@@ -1,5 +1,5 @@
 package OpenGL::Sandbox::V1::FTGLFont;
-BEGIN { $OpenGL::Sandbox::V1::FTGLFont::VERSION = '0.02'; }
+BEGIN { $OpenGL::Sandbox::V1::FTGLFont::VERSION = '0.03'; }
 use Moo;
 use Cwd;
 use OpenGL::Sandbox::MMap;
@@ -40,11 +40,8 @@ sub render {
 	$self->_ftgl_wrapper->render($text, @_ == 1 && ref $_[0] eq 'HASH'? %{$_[0]} : @_);
 }
 
-use Inline CPP => do { my $x= __FILE__; $x =~ s/\.pm$/\.cpp/; $x },
-	(defined $OpenGL::Sandbox::V1::FTGLFont::VERSION? (
-		NAME => __PACKAGE__,
-		VERSION => __PACKAGE__->VERSION
-	) : () ),
+use OpenGL::Sandbox::V1::FTGLFont::Inline
+	CPP => do { my $x= __FILE__; $x =~ s/\.pm$/\.cpp/; $x },
 	INC => '-I/usr/include/FTGL -I/usr/include/freetype2 -I'
 	       .do{ my $x= __FILE__; $x =~ s|/[^/]+$||; Cwd::abs_path($x) },
 	LIBS => '-lfreetype -lftgl';
@@ -63,7 +60,7 @@ OpenGL::Sandbox::V1::FTGLFont - Wrapper object for FTGL Fonts
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
